@@ -31,7 +31,10 @@ from util import (now_str, current_reports, latest_version,
 
 IMAGES_DIR = '/home/patchbot/sage-patchbot/src/images/'
 # oldest version of sage about which we still care
-OLDEST = '6.0'
+OLDEST = '7.0'
+
+# machines that are banned from posting their reports
+BLACKLIST = ['hera-OptiPlex-7010', 'librae']
 
 
 def timed_cached_function(refresh_rate=60):
@@ -182,7 +185,9 @@ def get_query(args):
 
         if 'base' in args:
             base = args.get('base')
-            if not(base == 'all' or base == 'latest'):
+            if base == 'latest' or base == 'develop':
+                query['reports.base'] = latest_base()
+            elif base != 'all':
                 query['reports.base'] = base
 
     query['milestone'] = {'$ne': 'sage-duplicate/invalid/wontfix'}
@@ -197,6 +202,16 @@ def get_query(args):
 def ticket_list():
     authors = None
     machine = None
+
+    if 'base' in request.args:
+        base = request.args.get('base')
+        if base == 'all':
+            base = None
+        elif base == 'develop':
+            base = 'latest'
+    else:
+        base = 'latest'
+
     query = get_query(request.args)
     if 'machine' in request.args:
         machine = request.args.get('machine').split(':')
@@ -209,13 +224,6 @@ def ticket_list():
     limit = int(request.args.get('limit', 1000))
     print(query)
 
-    if 'base' in request.args:
-        base = request.args.get('base')
-        if base == 'all':
-            base = None
-    else:
-        base = 'latest'
-
     all = patchbot.filter_on_authors(tickets.find(query).sort(order).limit(limit), authors)
     if 'raw' in request.args:
         # raw json file for communication with patchbot clients
@@ -318,11 +326,24 @@ def render_ticket(ticket):
     ?force will refresh the info in the patchbot-server database
 
     ?kick will tell the patchbot-clients to retry the ticket
+
+    ?base to select reports according to their base
     """
+    latest = latest_base()
+
+    if 'base' in request.args:
+        chosen_base = request.args.get('base')
+    else:
+        chosen_base = 'all' if ticket != 0 else 'develop'
+
+    if chosen_base == 'latest' or chosen_base == 'develop':
+        chosen_base = latest
+
     try:
         info = scrape(ticket, db=db, force='force' in request.args)
     except:
         info = tickets.find_one({'id': ticket})
+
     if info is None:
         return "No such ticket."
     if 'kick' in request.args:
@@ -340,8 +361,6 @@ def render_ticket(ticket):
     if old_reports != info['reports']:
         db.save_ticket(info)
 
-    base = latest_base()
-
     def format_info(info):
         new_info = {}
         for key, value in info.items():
@@ -377,10 +396,7 @@ def render_ticket(ticket):
                 new_info[key] = trust_check + auths
             elif key == 'participants':
                 parts = ', '.join("<a href='/ticket/?participant=%s'>%s</a>" % (a, a) for a in value)
-                trust_check = "(<a href='/trust_check?who="
-                trust_check += ','.join("{}".format(a) for a in value)
-                trust_check += "'>Check trust</a>) "
-                new_info[key] = trust_check + parts
+                new_info[key] = parts
             elif key == 'git_branch':
                 new_info[key] = '<a href="http://git.sagemath.org/sage.git/log/?h=%s">%s</a>' % (value, value)
             elif key == 'spkgs':
@@ -406,6 +422,7 @@ def render_ticket(ticket):
 
     def preprocess_reports(all):
         for item in all:
+            base_of_this_report = item['base']
             base_report = base_reports.get(item['base'] + "/" + "/".join(item['machine']), base_reports.get(item['base']))
             if base_report:
                 item['base_log'] = quote(log_name(0, base_report))
@@ -413,7 +430,7 @@ def render_ticket(ticket):
                 git_log = item.get('git_log')
                 item['git_log_len'] = '?' if git_log is None else len(git_log)
             item['raw_base'] = item['base']
-            if compare_version(item['base'], base) < 0:
+            if compare_version(item['base'], latest) < 0:
                 item['base'] = "<span style='color: red'>%s</span>" % item['base']
             if 'time' in item:
                 item['log'] = log_name(info['id'], item)
@@ -422,7 +439,8 @@ def render_ticket(ticket):
             for x in ('commit', 'base', 'merge'):
                 field = 'git_%s_human' % x
                 item[field] = format_git_describe(item.get(field, None))
-            yield item
+            if chosen_base == 'all' or chosen_base == base_of_this_report:
+                yield item
 
     def normalize_plugin(plugin):
         while len(plugin) < 3:
@@ -432,7 +450,7 @@ def render_ticket(ticket):
     def sort_fields(items):
         return sorted(items, key=(lambda x: (x[0] != 'title', x)))
 
-    status_data = get_ticket_status(info, base=base)[1]  # single status
+    status_data = get_ticket_status(info, base=latest)[1]  # single status
 
     return render_template("ticket.html",
                            reports=preprocess_reports(info['reports']),
@@ -471,6 +489,8 @@ def reports_by_machine_and_base(ticket):
 def render_ticket_status(ticket):
     """
     Return the status image for the given ticket.
+
+    This now only renders a png image with the base.
     """
     try:
         if 'fast' in request.args:
@@ -485,14 +505,14 @@ def render_ticket_status(ticket):
     else:
         base = latest_version(info.get('reports', []))
 
-    status = get_ticket_status(info, base=base)[2]  # composite status
+    # status = get_ticket_status(info, base=base)[2]  # composite status
 
     if 'fast' in request.args:
         display_base = None
     else:
         display_base = base
 
-    response = make_response(create_status_image(status, base=display_base))
+    response = make_response(create_base_image(base=display_base))
     response.headers['Content-type'] = 'image/png'
     response.headers['Cache-Control'] = 'no-cache'
     return response
@@ -540,7 +560,13 @@ def post_report(ticket_id):
         report = json.loads(request.form.get('report'))
         assert (isinstance(report, dict)), "report is not a dict"
         for fld in ['status', 'spkgs', 'base', 'machine', 'time']:
-            assert (fld in report), "{} missing in report".format(fld)
+                assert (fld in report), "{} missing in report".format(fld)
+
+        machine_name = report['machine'][-1]
+        if machine_name in BLACKLIST:
+            msg = 'machine {} is blacklisted'.format(machine_name)
+            raise RuntimeError(msg)
+
         patchbot.prune_pending(ticket, report['machine'])
         ticket['reports'].append(report)
         db.logs.put(request.files.get('log'), _id=log_name(ticket_id, report))
@@ -757,6 +783,36 @@ def status_image_path(status, type='png'):
         return IMAGES_DIR + 'icon-{}.svg'.format(status)
 
 
+def create_base_image(base=None):
+    """
+    Return a png image containing only the sage version for the latest base
+
+    This is for the 'png' icon set.
+
+    INPUT:
+
+    - base -- the base
+
+    EXAMPLES::
+
+        create_base_image('6.4')
+    """
+    path = IMAGES_DIR + 'icon-Empty.png'  # should be done in SVG instead
+    if base is None:
+        base = ''
+    base = base.replace("alpha", "a").replace("beta", "b")
+    try:
+        from PIL import Image, ImageDraw
+        im = Image.open(path)
+        wx, wy = ImageDraw.Draw(im).textsize(base)
+        ImageDraw.Draw(im).text(((48 - wx) // 2, 18), base, fill='#000000')
+        output = StringIO()
+        im.save(output, format='png')
+        return output.getvalue()
+    except ImportError:
+        return open(path).read()
+
+
 def create_status_image(status, base=None):
     """
     Return a composite blob image for a concatenation of status
@@ -859,7 +915,7 @@ def robots():
 @app.route("/favicon.ico")
 def favicon():
     """
-    Return the favicon image as a web page (green blob)
+    Return the favicon image as a web page (green icon)
 
     See http://patchbot.sagemath.org/favicon.ico for the result.
 
@@ -868,7 +924,7 @@ def favicon():
         sage: from serve import favicon
         sage: favicon()
     """
-    response = make_response(open(IMAGES_DIR + 'icon-TestsPassed.png').read())
+    response = make_response(open(IMAGES_DIR + 'favicon.png').read())
     response.headers['Content-type'] = 'image/png'
     return response
 
